@@ -38,6 +38,7 @@ import pyarrow.compute as pc
 import pyarrow.dataset
 import s3fs
 
+from pygeoapi.crs import crs_transform
 from pygeoapi.provider.base import (
     BaseProvider,
     ProviderConnectionError,
@@ -45,7 +46,6 @@ from pygeoapi.provider.base import (
     ProviderItemNotFoundError,
     ProviderQueryError,
 )
-from pygeoapi.util import crs_transform
 
 LOGGER = logging.getLogger(__name__)
 
@@ -125,8 +125,8 @@ class ParquetProvider(BaseProvider):
             geo_metadata = json.loads(self.ds.schema.metadata[b'geo'])
             geom_column = geo_metadata['primary_column']
             # if the CRS is not set default to EPSG:4326, per geoparquet spec
-            self.crs = (geo_metadata['columns'][geom_column]['crs']
-                        or 'EPSG:4326')
+            self.crs = (geo_metadata['columns'][geom_column].get('crs')
+                        or 'OGC:CRS84')
 
     def _read_parquet(self, return_scanner=False, **kwargs):
         """
