@@ -63,7 +63,6 @@ from geoalchemy2 import Geometry  # noqa - this isn't used explicitly but is nee
 from geoalchemy2.functions import ST_MakeEnvelope, ST_Intersects
 from geoalchemy2.shape import to_shape, from_shape
 from pygeofilter.backends.sqlalchemy.evaluate import to_filter
-import pyproj
 import shapely
 from sqlalchemy.sql import func
 from sqlalchemy import (
@@ -84,6 +83,7 @@ from sqlalchemy.ext.automap import automap_base
 from sqlalchemy.orm import Session, load_only
 from sqlalchemy.sql.expression import and_
 
+from pygeoapi.crs import get_transform_from_spec, get_srid
 from pygeoapi.provider.base import (
     BaseProvider,
     ProviderConnectionError,
@@ -91,8 +91,6 @@ from pygeoapi.provider.base import (
     ProviderQueryError,
     ProviderItemNotFoundError
 )
-from pygeoapi.util import get_transform_from_crs, get_crs_from_uri
-
 
 LOGGER = logging.getLogger(__name__)
 
@@ -134,12 +132,6 @@ class GenericSQLProvider(BaseProvider):
         LOGGER.debug(f'Table: {self.table}')
         LOGGER.debug(f'ID field: {self.id_field}')
         LOGGER.debug(f'Geometry field: {self.geom}')
-
-        # conforming to the docs:
-        # https://docs.pygeoapi.io/en/latest/data-publishing/ogcapi-features.html#connection-examples # noqa
-        self.storage_crs = provider_def.get(
-            'storage_crs', 'https://www.opengis.net/def/crs/OGC/0/CRS84'
-        )
         LOGGER.debug(f'Configured Storage CRS: {self.storage_crs}')
 
         # Read table information from database
@@ -235,14 +227,15 @@ class GenericSQLProvider(BaseProvider):
             if resulttype == 'hits' or not results:
                 return response
 
-            crs_transform_out = self._get_crs_transform(crs_transform_spec)
+            crs_transform_out = get_transform_from_spec(crs_transform_spec)
 
             for item in (
                 results.order_by(*order_by_clauses).offset(offset).limit(limit)
             ):
                 response['numberReturned'] += 1
                 response['features'].append(
-                    self._sqlalchemy_to_feature(item, crs_transform_out)
+                    self._sqlalchemy_to_feature(item, crs_transform_out,
+                                                select_properties)
                 )
 
         return response
@@ -333,7 +326,7 @@ class GenericSQLProvider(BaseProvider):
             if item is None:
                 msg = f'No such item: {self.id_field}={identifier}.'
                 raise ProviderItemNotFoundError(msg)
-            crs_transform_out = self._get_crs_transform(crs_transform_spec)
+            crs_transform_out = get_transform_from_spec(crs_transform_spec)
             feature = self._sqlalchemy_to_feature(item, crs_transform_out)
 
             # Drop non-defined properties
@@ -447,18 +440,29 @@ class GenericSQLProvider(BaseProvider):
             if not isinstance(v, dict)
         }
 
-    def _sqlalchemy_to_feature(self, item, crs_transform_out=None):
-        feature = {'type': 'Feature'}
+    def _sqlalchemy_to_feature(self, item, crs_transform_out=None,
+                               select_properties=[]):
+        """
+        Helper function to transform an SQLAlchemy result to a
+        GeoJSON feature.
+
+        :param item: SQLAlchemy result
+        :param crs_transform_out: CRS transformation
+        :param select_properties: additional properties to filter on
+
+        :returns: `dict` of GeoJSON feature
+        """
+
+        feature = {'type': 'Feature', 'properties': {}}
 
-        # Add properties from item
         item_dict = item.__dict__
-        item_dict.pop('_sa_instance_state')  # Internal SQLAlchemy metadata
-        feature['properties'] = item_dict
-        feature['id'] = item_dict.pop(self.id_field)
+
+        # set feature id
+        feature['id'] = item_dict[self.id_field]
 
         # Convert geometry to GeoJSON style
-        if feature['properties'].get(self.geom):
-            wkb_geom = feature['properties'].pop(self.geom)
+        if item_dict.get(self.geom) is not None:
+            wkb_geom = item_dict[self.geom]
             try:
                 shapely_geom = to_shape(wkb_geom)
             except TypeError:
@@ -470,6 +474,11 @@ class GenericSQLProvider(BaseProvider):
         else:
             feature['geometry'] = None
 
+        keys = select_properties or self.fields.keys()
+        for key in keys:
+            if key in item_dict:
+                feature['properties'][key] = item_dict[key]
+
         return feature
 
     def _feature_to_sqlalchemy(self, json_data, identifier=None):
@@ -479,10 +488,7 @@ class GenericSQLProvider(BaseProvider):
         attributes.pop('identifier', None)
         attributes[self.geom] = from_shape(
             shapely.geometry.shape(json_data['geometry']),
-            # NOTE: for some reason, postgis in the github action requires
-            # explicit crs information. i think it's valid to assume 4326:
-            # https://portal.ogc.org/files/108198#feature-crs
-            srid=pyproj.CRS.from_user_input(self.storage_crs).to_epsg()
+            srid=get_srid(self.storage_crs)
         )
         attributes[self.id_field] = identifier
 
@@ -567,17 +573,19 @@ class GenericSQLProvider(BaseProvider):
     def _select_properties_clause(self, select_properties, skip_geometry):
         # List the column names that we want
         if select_properties:
-            column_names = set(select_properties)
+            column_names = sorted(set(select_properties),
+                                  key=select_properties.index)
         else:
             # get_fields() doesn't include geometry column
-            column_names = set(self.fields.keys())
+            column_names = self.fields.keys()
 
         if self.properties:  # optional subset of properties defined in config
-            properties_from_config = set(self.properties)
-            column_names = column_names.intersection(properties_from_config)
+            properties_from_config = self.properties
+            column_names = column_names and properties_from_config
 
         if not skip_geometry:
-            column_names.add(self.geom)
+            column_names = list(column_names)
+            column_names.append(self.geom)
 
         # Convert names to SQL Alchemy clause
         selected_columns = []
@@ -591,16 +599,6 @@ class GenericSQLProvider(BaseProvider):
 
         return selected_properties_clause
 
-    def _get_crs_transform(self, crs_transform_spec=None):
-        if crs_transform_spec is not None:
-            crs_transform = get_transform_from_crs(
-                pyproj.CRS.from_wkt(crs_transform_spec.source_crs_wkt),
-                pyproj.CRS.from_wkt(crs_transform_spec.target_crs_wkt)
-            )
-        else:
-            crs_transform = None
-        return crs_transform
-
 
 @functools.cache
 def get_engine(
@@ -648,10 +646,23 @@ def get_table_model(
             f'Could not connect to {repr(engine.url)} (password hidden).'
         )
     except InvalidRequestError:
-        raise ProviderQueryError(
+        msg = (
             f"Table '{table_name}' not found in schema '{schema}' "
             f'on {repr(engine.url)}.'
         )
+        LOGGER.error(msg)
+
+        if len(db_search_path) > 1:
+            # If the table is not found in the first schema, try the next one
+            return get_table_model(
+                table_name,
+                id_field,
+                db_search_path[1:],
+                engine
+            )
+        else:
+            # If the table is not found in any schema, raise an error
+            raise ProviderQueryError(msg)
 
     # Create SQLAlchemy model from reflected table
     # It is necessary to add the primary key constraint because SQLAlchemy
@@ -719,9 +730,8 @@ class PostgreSQLProvider(GenericSQLProvider):
         if not bbox:
             return True  # Let everything through if no bbox
 
-        # Since this provider uses postgis, we can use ST_MakeEnvelope
-        storage_srid = get_crs_from_uri(self.storage_crs).to_epsg()
-        envelope = ST_MakeEnvelope(*bbox, storage_srid or 4326)
+        storage_srid = get_srid(self.storage_crs)
+        envelope = ST_MakeEnvelope(*bbox, storage_srid)
 
         geom_column = getattr(self.table_model, self.geom)
         bbox_filter = ST_Intersects(envelope, geom_column)
