@@ -4,7 +4,7 @@
 #
 # Authors: Francesco Bartoli <xbartolone@gmail.com>
 #
-# Copyright (c) 2024 Francesco Bartoli
+# Copyright (c) 2025 Francesco Bartoli
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -31,13 +31,18 @@
 
 from enum import Enum
 
-from pydantic import RootModel
+from pydantic import BaseModel
+import pydantic
 
 
 class SupportedFormats(Enum):
-    JSON = "json"
-    YAML = "yaml"
+    JSON = 'json'
+    YAML = 'yaml'
 
-
-class OAPIFormat(RootModel):
-    root: SupportedFormats = SupportedFormats.YAML
+# Handle Pydantic v1/v2 compatibility
+if pydantic.VERSION.startswith('1'):
+    class OAPIFormat(BaseModel):
+        __root__: SupportedFormats = SupportedFormats.YAML
+else:
+    class OAPIFormat(BaseModel):
+        root: SupportedFormats = SupportedFormats.YAML
