@@ -32,9 +32,10 @@ import json
 import logging
 from requests import Session, codes
 
+from pygeoapi.crs import crs_transform, get_srid
 from pygeoapi.provider.base import (BaseProvider, ProviderConnectionError,
                                     ProviderTypeError, ProviderQueryError)
-from pygeoapi.util import format_datetime, crs_transform
+from pygeoapi.util import format_datetime
 
 LOGGER = logging.getLogger(__name__)
 
@@ -59,11 +60,12 @@ class ESRIServiceProvider(BaseProvider):
         super().__init__(provider_def)
 
         self.url = f'{self.data}/query'
-        self.crs = provider_def.get('crs', '4326')
+        self.crs = get_srid(self.storage_crs)
         self.username = provider_def.get('username')
         self.password = provider_def.get('password')
+        self.token_url = provider_def.get('token_service', ARCGIS_URL)
+        self.token_referer = provider_def.get('referer', GENERATE_TOKEN_URL)
         self.token = None
-
         self.session = Session()
 
         self.login()
@@ -76,7 +78,7 @@ class ESRIServiceProvider(BaseProvider):
         :returns: `dict` of fields
         """
 
-        if not self.fields:
+        if not self._fields:
             # Load fields
             params = {'f': 'pjson'}
             resp = self.get_response(self.data, params=params)
@@ -102,9 +104,9 @@ class ESRIServiceProvider(BaseProvider):
                 raise ProviderTypeError(msg)
 
             for _ in resp['fields']:
-                self.fields.update({_['name']: {'type': _['type']}})
+                self._fields.update({_['name']: {'type': _['type']}})
 
-        return self.fields
+        return self._fields
 
     @crs_transform
     def query(self, offset=0, limit=10, resulttype='results',
@@ -194,16 +196,15 @@ class ESRIServiceProvider(BaseProvider):
                 msg = 'Missing ESRI login information, not setting token'
                 LOGGER.debug(msg)
                 return
-
             params = {
                 'f': 'pjson',
                 'username': self.username,
                 'password': self.password,
-                'referer': ARCGIS_URL
+                'referer': self.token_referer
             }
 
             LOGGER.debug('Logging in')
-            with self.session.post(GENERATE_TOKEN_URL, data=params) as r:
+            with self.session.post(self.token_url, data=params) as r:
                 self.token = r.json().get('token')
                 # https://enterprise.arcgis.com/en/server/latest/administer/windows/about-arcgis-tokens.htm
                 self.session.headers.update({
