@@ -36,10 +36,11 @@ from dateutil.parser import parse as parse_date
 from shapely.geometry import shape
 from tinydb import TinyDB, Query, where
 
+from pygeoapi.crs import crs_transform
 from pygeoapi.provider.base import (BaseProvider, ProviderConnectionError,
                                     ProviderInvalidQueryError,
                                     ProviderItemNotFoundError)
-from pygeoapi.util import crs_transform, get_typed_value
+from pygeoapi.util import get_typed_value
 
 LOGGER = logging.getLogger(__name__)
 
@@ -116,6 +117,24 @@ class TinyDBProvider(BaseProvider):
 
         return self._fields
 
+    def get_domains(self, properties=[], current=False) -> tuple:
+        records = self.query()
+        domains = {}
+
+        if properties:
+            keys = properties
+        else:
+            keys = records['features'][0]['properties'].keys()
+
+        for key in keys:
+            v = [x['properties'][key] for x in records['features']]
+            v = set([v2 for v2 in v if v2 is not None and isinstance(v2, (float, int, str))])  # noqa
+
+            if v:
+                domains[key] = list(v)
+
+        return domains, True
+
     @crs_transform
     def query(self, offset=0, limit=10, resulttype='results',
               bbox=[], datetime_=None, properties=[], sortby=[],
@@ -383,11 +402,45 @@ class TinyDBCatalogueProvider(TinyDBProvider):
 
         return json_data
 
+    def _prepare_q_param_with_spaces(self, s: str) -> str:
+        """
+        Prepare a search statement for the search term `s`.
+        The term `s` might have spaces.
+
+        Examples (f is shorthand for Q.properties["_metadata-anytext"]):
+        +---------------+--------------------+
+        | search term   | TinyDB search      |
+        +---------------+--------------------+
+        | 'aa'          | f.search('aa')     |
+        | 'aa bb'       | f.search('aa +bb') |
+        | '  aa   bb  ' | f.search('aa +bb') |
+        +---------------+--------------------+
+        """
+        return 'Q.properties["_metadata-anytext"].search("' \
+            + ' +'.join(s.split()) \
+            + '", flags=re.IGNORECASE)'
+
     def _add_search_query(self, query: list, search_term: str = None) -> str:
-        if search_term is not None:
+        """
+        Create a search query according to the OGC API - Records specification.
+
+        https://docs.ogc.org/is/20-004r1/20-004r1.html (Listing 14)
+
+        Examples (f is shorthand for Q.properties["_metadata-anytext"]):
+        +-------------+-----------------------------------+
+        | search term | TinyDB search                     |
+        +-------------+-----------------------------------+
+        | 'aa'        | f.search('aa')                    |
+        | 'aa,bb'     | f.search('aa')|f.search('bb')     |
+        | 'aa,bb cc'  | f.search('aa')|f.search('bb +cc') |
+        +-------------+-----------------------------------+
+        """
+        if search_term is not None and len(search_term) > 0:
             LOGGER.debug('catalogue q= query')
-            for t in search_term.split():
-                query.append(f"(Q.properties['_metadata-anytext'].search('{t}', flags=re.IGNORECASE))")  # noqa
+            terms = [s for s in search_term.split(',') if len(s) > 0]
+            query.append('|'.join(
+                [self._prepare_q_param_with_spaces(t) for t in terms]
+            ))
 
         return query
 
